@@ -46,7 +46,10 @@ class Dataset(CoreAPI, DatasetRef):
                             key=root_directory, name='', etag=None, last_modified=None, size_bytes=None)
 
     def __repr__(self) -> str:
-        return f"<Dataset: {self.namespace} - {self.dataset_name}>"
+        if self.delete_status != DeleteStatus.NOT_SCHEDULED:
+            return f"<Dataset: {self.namespace} - {self.dataset_name} (DELETE STATUS: {self.delete_status.value})>"
+        else:
+            return f"<Dataset: {self.namespace} - {self.dataset_name}>"
 
     def display(self):
         """Helper to print some useful info about the dataset"""
@@ -57,6 +60,9 @@ class Dataset(CoreAPI, DatasetRef):
         print(f"Created On: {self.created_on}")
         print(f"Root Directory: {self.root_directory}")
         print(f"Owner: {self.owner}")
+        print(f"Delete Status: {self.delete_status.value}")
+        if self.delete_status != DeleteStatus.NOT_SCHEDULED:
+            print(f"Delete On: {self.delete_on}")
         print("Permissions:")
         for u, p in self.permissions.items():
             print(f"\t{u}: {p}")
