@@ -338,6 +338,9 @@ def upload_directory(dataset_name: str, directory: str, namespace: str, endpoint
             # Lots got skipped, so just print a summary
             _log(f"Skipping {len(exist_objs)} files out of {len(files_sorted)} that already exist.")
 
+        # Reset the boto3 client in the object store before pickling occurs.
+        ds.namespace.object_store.reset_client()
+
         force_quit = False
         if num_to_upload > 0:
             _log(f"Uploading {num_to_upload} files.")
@@ -520,7 +523,7 @@ def _upload_worker(work_queue: Queue, status_queue: Queue, dataset: Dataset,
     """
     # Reset the boto3 client in the object store that was passed in. This is important to do before the client is
     # used across processes as this is not a safe operation.
-    dataset.namespace.object_store.reset_client(dataset.namespace.name)
+    dataset.namespace.object_store.reset_client()
 
     while True:
         try:
